Coverage report

File | class | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | --- | ---
src/regex_template/__init__.py | (no class) | 22 | 0 | 0 | 10 | 0 | 100%
tests/__init__.py | (no class) | 0 | 0 | 0 | 0 | 0 | 100%
tests/test_regex_template.py | TestCompileWithRegularStrings | 10 | 0 | 0 | 0 | 0 | 100%
tests/test_regex_template.py | TestCompileWithTStrings | 63 | 0 | 0 | 0 | 0 | 100%
tests/test_regex_template.py | TestSafeFormatSpecifier | 17 | 0 | 0 | 0 | 0 | 100%
tests/test_regex_template.py | TestRegexFlags | 15 | 0 | 0 | 0 | 0 | 100%
tests/test_regex_template.py | TestEdgeCases | 37 | 0 | 0 | 0 | 0 | 100%
tests/test_regex_template.py | TestErrorHandling | 9 | 0 | 0 | 0 | 0 | 100%
tests/test_regex_template.py | TestPropertyBasedTests | 10 | 0 | 0 | 0 | 0 | 100%
tests/test_regex_template.py | (no class) | 55 | 0 | 0 | 0 | 0 | 100%
Total |  | 238 | 0 | 0 | 10 | 0 | 100%

No items found using the specified filter.